README
======
```
                                                     .o88Oo._
                                                    d8P         .ooOO8bo._
                                                    88                  '*Y8bo.
                                      __            YA                      '*Y8b   __
                                    ,dPYb,           YA                        68o68**8Oo.
                                    IP'`Yb            "8D                       *"'    "Y8o
                                    I8  8I             Y8     'YB                       .8D
                                    I8  8P             '8               d8'             8D
                                    I8  8'              8       d8888b          d      AY
     ,gggo,    ,ggggo,    ,gggo,gg  I8 dP    ,gggo,gg   Y,     d888888         d'  _.oP"
    dP"  "Yb  dP"  "Y8go*8P"  "Y8I  I8dP    dP"  "Y8I    q.    Y8888P'        d8
   i8'       i8'    ,8P i8'    ,8I  I8P    i8'    ,8I     "q.  `Y88P'       d8"
  ,d8,_    _,d8,   ,d8' d8,   ,d8b,,d8b,_ ,d8,   ,d8b,       Y           ,o8P
ooP""Y8888PP*"Y8888P"   "Y8888P"`Y88P'"Y88P"Y8888P"`Y8            oooo888P"
```

INSTALLATION
============

coala can be installed with `pip install coala`. If you need more
information about the installation and dependencies, take a look at our
[installation documentation](http://coala.rtfd.org/en/latest/Users/Install/).

The latest code from master is automatically deployed to PyPI as a development
version. Get it with `pip install coala --pre`.

[![PyPI](https://img.shields.io/pypi/pyversions/coala.svg)](https://pypi.python.org/pypi/coala)

USAGE
=====

If you want to learn more about coala, its functionality and its usage, please
take a look at our
[tutorial](http://coala.rtfd.org/en/latest/Users/Tutorial/).

ABOUT
=====

coala is a simple COde AnaLysis Application. Its goal is to make static code
analysis easy while remaining completely modular and therefore extendable and
language independent.

Read more at our [documentation](http://coala.rtfd.org/).

Authors
-------

coala is maintained by a growing community. Please take a look at the meta
information in [setup.py](setup.py) for current maintainers.

Project Status
--------------

[![Linux Build Status](https://img.shields.io/circleci/project/coala-analyzer/coala/master.svg?label=linux%20build)](https://circleci.com/gh/coala-analyzer/coala) [![Windows Build status](https://img.shields.io/appveyor/ci/sils1297/coala/master.svg?label=windows%20build)](https://ci.appveyor.com/project/sils1297/coala/branch/master) [![OSX Build status](https://img.shields.io/travis/coala-analyzer/coala/master.svg?label=osx%20build)](https://travis-ci.org/coala-analyzer/coala)

[![Codacy Code Quality](https://img.shields.io/codacy/f0ac979fa93f49509cba9086754a50d4.svg?label=codacy quality)](https://www.codacy.com/app/lasse/coala) [![Scrutinizer Code Quality](https://img.shields.io/scrutinizer/g/coala-analyzer/coala.svg?label=scrutinizer quality)](https://scrutinizer-ci.com/g/coala-analyzer/coala/?branch=master) [![codecov.io](https://img.shields.io/codecov/c/github/coala-analyzer/coala/master.svg?label=branch coverage)](https://codecov.io/github/coala-analyzer/coala?branch=master)

[![Documentation Status](https://readthedocs.org/projects/coala/badge/?version=latest)](https://readthedocs.org/projects/coala/?badge=latest)

GETTING INVOLVED
================

If you want to contribute to coala, please take a look at the
[Getting Involved Information](http://coala.readthedocs.org/en/latest/Getting_Involved/README/).

We appreciate any help!

[![https://gitter.im/coala-analyzer/coala](https://img.shields.io/badge/gitter-join%20chat%20%E2%86%92-brightgreen.svg)](https://gitter.im/coala-analyzer/coala)

LICENSE
=======

[![AGPL](https://img.shields.io/github/license/coala-analyzer/coala.svg)](https://www.gnu.org/licenses/agpl-3.0.html)

This code falls under the GNU Affero General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your option)
any later version.

Please note that some directories may have an own license. Summary of all
licenses used:

 * GNU AGPLv3 (default for all code)
 * LLVM Release License (coalib/bearlib/parsing/clang)
